summaryrefslogtreecommitdiff
path: root/src/jit/inlinepolicy.cpp
diff options
context:
space:
mode:
authorAndy Ayers <andya@microsoft.com>2016-07-15 13:06:44 -0700
committerAndy Ayers <andya@microsoft.com>2016-07-15 13:06:44 -0700
commit10af6af8d2254f3ce8a4f4050bac29c7e5b13de1 (patch)
tree5961258f27b946392f3a3ce341b0737df143673c /src/jit/inlinepolicy.cpp
parent361edab2925026970715546bdc7ccca0b6c058cd (diff)
downloadcoreclr-10af6af8d2254f3ce8a4f4050bac29c7e5b13de1.tar.gz
coreclr-10af6af8d2254f3ce8a4f4050bac29c7e5b13de1.tar.bz2
coreclr-10af6af8d2254f3ce8a4f4050bac29c7e5b13de1.zip
Inliner: capture profit model estimate during replay
When using ReplayPolicy and dumping data, capture the profitability estimate made by the ModelPolicy, so we can more easily cross-validate it against externally measured profitability.
Diffstat (limited to 'src/jit/inlinepolicy.cpp')
-rw-r--r--src/jit/inlinepolicy.cpp5
1 files changed, 3 insertions, 2 deletions
diff --git a/src/jit/inlinepolicy.cpp b/src/jit/inlinepolicy.cpp
index eee337eead..b3ec841a39 100644
--- a/src/jit/inlinepolicy.cpp
+++ b/src/jit/inlinepolicy.cpp
@@ -2685,12 +2685,13 @@ void ReplayPolicy::DetermineProfitability(CORINFO_METHOD_INFO* methodInfo)
}
// If we're also dumping inline data, make additional observations
// based on the method info, and estimate code size, so that the
// reports have the necessary data.
if (JitConfig.JitInlineDumpData() != 0)
{
MethodInfoObservations(methodInfo);
EstimateCodeSize();
+ EstimatePerformanceImpact();
m_IsForceInline = m_WasForceInline;
}
@@ -2685,12 +2685,13 @@ void ReplayPolicy::DetermineProfitability(CORINFO_METHOD_INFO* methodInfo)
}
// If we're also dumping inline data, make additional observations
- // based on the method info, and estimate code size, so that the
- // reports have the necessary data.
+ // based on the method info, and estimate code size and perf
+ // impact, so that the reports have the necessary data.
if (JitConfig.JitInlineDumpData() != 0)
{